@@ -1,8 +1,12 @@
 from unittest.mock import patch
 
-from gitlint import rules
-from gitlint.config import LintConfig, LintConfigError, LintConfigGenerator, GITLINT_CONFIG_TEMPLATE_SRC_PATH
-from gitlint import options
+from gitlint import options, rules
+from gitlint.config import (
+    GITLINT_CONFIG_TEMPLATE_SRC_PATH,
+    LintConfig,
+    LintConfigError,
+    LintConfigGenerator,
+)
 from gitlint.tests.base import BaseTestCase
 
 
@@ -166,7 +170,7 @@ class LintConfigTests(BaseTestCase):
         # UserRuleError, RuleOptionError should be re-raised as LintConfigErrors
         side_effects = [rules.UserRuleError("üser-rule"), options.RuleOptionError("rüle-option")]
         for side_effect in side_effects:
-            with patch("gitlint.config.rule_finder.find_rule_classes", side_effect=side_effect):
+            with patch("gitlint.config.rule_finder.find_rule_classes", side_effect=side_effect):  # noqa: SIM117
                 with self.assertRaisesMessage(LintConfigError, str(side_effect)):
                     config.contrib = "contrib-title-conventional-commits"
 
