@@ -1,17 +1,13 @@
-
-# -*- coding: utf-8 -*-
-from gitlint.tests.base import BaseTestCase
-from gitlint.rules import RuleViolation
-from gitlint.contrib.rules.signedoff_by import SignedOffBy
-
 from gitlint.config import LintConfig
+from gitlint.contrib.rules.signedoff_by import SignedOffBy
+from gitlint.rules import RuleViolation
+from gitlint.tests.base import BaseTestCase
 
 
 class ContribSignedOffByTests(BaseTestCase):
-
     def test_enable(self):
         # Test that rule can be enabled in config
-        for rule_ref in ['CC1', 'contrib-body-requires-signed-off-by']:
+        for rule_ref in ["CC1", "contrib-body-requires-signed-off-by"]:
             config = LintConfig()
             config.contrib = [rule_ref]
             self.assertIn(SignedOffBy(), config.rules)
