@@ -1,5 +1,5 @@
-from gitlint.rules import CommitRule, RuleViolation
 from gitlint.options import IntOption
+from gitlint.rules import CommitRule, RuleViolation
 
 
 class MyUserCommitRule(CommitRule):
@@ -19,7 +19,7 @@ class MyUserCommitRule(CommitRule):
 
 
 def func_should_be_ignored():
-    pass
+    pass  # pragma: nocover
 
 
 global_variable_should_be_ignored = True
